pyLife Documentation
====================

.. toctree::
   :maxdepth: 1
   :caption: About

   README

.. toctree::
   :maxdepth: 1
   :caption: Installation / Getting started

   INSTALLATION

.. toctree::
   :maxdepth: 2

   tutorials

.. toctree::
   :maxdepth: 2
   :caption: User Guide

   user_guide

.. toctree::
   :maxdepth: 1
   :caption: Cookbook

   cookbook

.. toctree::
   :maxdepth: 1
   :caption: Reference

   reference

.. toctree::
   :maxdepth: 1
   :caption: Additional tools

   tools/index.rst

.. toctree::
   :maxdepth: 1
   :caption: News

   NEWS-2.0
   CHANGELOG

.. toctree::
   :maxdepth: 1
   :caption: Hack pyLife

   CONTRIBUTING
   CODINGSTYLE
   variable_names

.. toctree::
   :maxdepth: 1
   :caption: Licenses

   NOTICE
   LICENSE
   3rd-party-licenses


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
